@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package RT::Extension::Announce;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 RT->AddJavaScript('announce.js');
 RT->AddStyleSheets('announce.css');
@@ -88,6 +88,10 @@ sub GetAnnouncements {
 
 RT-Extension-Announce - Display announcements as a banner on RT pages.
 
+=head1 RT VERSION
+
+Works with RT 4.0 and 4.2.
+
 =head1 INSTALLATION
 
 =over
@@ -102,16 +106,22 @@ May need root permissions
 
 =item Edit your /opt/rt4/etc/RT_SiteConfig.pm
 
-Add these lines:
+If you are using RT 4.2 or later, add this line:
 
-    Set(@Plugins, qw(RT::Extension::Announce));
-    Set(@CustomFieldValuesSources, (qw(RT::CustomFieldValues::AnnounceGroups)));
+    Plugin('RT::Extension::Announce');
 
 or add C<RT::Extension::Announce> to your existing C<@Plugins> line.
 
+And add the following:
+
+    Set(@CustomFieldValuesSources, (qw(RT::CustomFieldValues::AnnounceGroups)));
+
+See L</CONFIGURATION> for more options.
+
 =item make initdb
 
 Run this in the install directory where you ran the previous make commands.
+Only run for an initial install. Do not run when upgrading.
 
 =item Clear your mason cache
 
@@ -123,17 +133,19 @@ Run this in the install directory where you ran the previous make commands.
 
 =head1 DESCRIPTION
 
-The Announce extension gives you an easy way to insert announcements on the RT homepage
-so all users can see the message. You may want to display a banner during maintenance or
-an unscheduled outage to make sure the people fielding customer tickets know that
-something is going on.
+The Announce extension gives you an easy way to insert announcements on the RT
+homepage so all users can see the message. You may want to display a banner
+during maintenance or an unscheduled outage to make sure the people fielding
+customer tickets know that something is going on.
+
+=for html <p><img src="https://raw.github.com/bestpractical/rt-extension-announce/master/doc/images/announce-screenshot.png" alt="RT Announcement on Homepage" /></p>
 
 =head1 DETAILS
 
 When you install the extension, a new queue is created called RTAnnounce.
-To post an announcement, create a ticket in that queue.
-The extension displays on the RT homepage the subject and most recent correspondence
-on active tickets in the RTAnnounce queue. As the incident or maintenance progresses,
+To post an announcement, create a ticket in that queue. The extension displays
+on the RT homepage the subject and most recent correspondence on active
+tickets in the RTAnnounce queue. As the incident or maintenance progresses,
 just reply to the ticket and the announcement will be updated with the latest
 information.
 
@@ -141,8 +153,8 @@ When multiple announcements are active, they are ordered by
 the last update time with the announcement with the most recent
 update coming first.
 
-When the incident is over, resolve the ticket and the
-announcement will be removed.
+When the incident is over, resolve the ticket and the announcement will be
+removed.
 
 Comments on announce tickets are not shown in the announcement. However,
 comments are visible on the ticket for users who have permission to view
@@ -177,13 +189,27 @@ notification list.
 
 =head1 CONFIGURATION
 
-You can change the name of the queue used for announcements. First edit the
-RTAnnounce queue in RT and change its name to your new name. Add a line
+=head2 C<$RTAnnounceQueue>
+
+Use this to change the name of the queue used for announcements. First edit the
+RTAnnounce queue in RT and change its name to your new name. Then a line
 to your RT_SiteConfig.pm to set that new value:
 
     Set($RTAnnounceQueue, 'Custom Announce Name');
 
-Then clear your mason cache and restart your server.
+=head2 C<@AnnounceGroups>
+
+By default, all user defined groups will be listed in "Announcement
+Groups". If you have a large number of groups in your RT, this can make for
+a long list, so you can customize the group list by setting C<@AnnounceGroups>
+in your RT_SiteConfig.pm:
+
+    Set(@AnnounceGroups, 'foo', 'bar', 'baz');
+
+=head2 C<$ShowAnnouncementsInSelfService>
+
+Set this to true to show announcements on the self service page as well as
+the regular privileged RT page.
 
 =head1 AUTHOR
 
@@ -193,7 +219,7 @@ Jim Brandt <jbrandt@bestpractical.com>
 
 All bugs should be reported via
 L<http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-Announce>
-or L<bug-RT-Extension-Announce@rt.cpan.org>.
+or bug-RT-Extension-Announce@rt.cpan.org.
 
 
 =head1 LICENSE AND COPYRIGHT
